==> create-exposed-app-8.1.0.tgz: package/CHANGELOG.md <==
# Changelog

<!-- markdownlint-disable -->

## [8.1.0](https://www.github.com/iamturns/create-exposed-app/compare/v8.0.1...v8.1.0) (2021-03-13)


### Features

* include instructions for NPM_TOKEN setup ([#126](https://www.github.com/iamturns/create-exposed-app/issues/126)) ([aa51d3c](https://www.github.com/iamturns/create-exposed-app/commit/aa51d3cb7641eed6ea39487f570d39de256988fa))


### Bug Fixes

* failing build script ([#127](https://www.github.com/iamturns/create-exposed-app/issues/127)) ([f7b6004](https://www.github.com/iamturns/create-exposed-app/commit/f7b60044c860854a916df0141f6ba96086d0f375))

### [8.0.1](https://www.github.com/iamturns/create-exposed-app/compare/v8.0.0...v8.0.1) (2021-03-13)

### Bug Fixes

- build badge ([#123](https://www.github.com/iamturns/create-exposed-app/issues/123)) ([1c5ada3](https://www.github.com/iamturns/create-exposed-app/commit/1c5ada36509579bb907ad725a497f0d3008b81e2))

## [8.0.0](https://www.github.com/iamturns/create-exposed-app/compare/v7.2.0...v8.0.0) (2021-03-13)

### ⚠ BREAKING CHANGES

A complete overhaul. Some highlights:

- Dropping CircleCI for Github Action (with auto-formatting, coverage reports, and release management)
- Dropping Babel for ESBuild
- Dropping semantic-release for Release Please

### Features

- Complete overhaul ([#121](https://www.github.com/iamturns/create-exposed-app/issues/121)) ([71f3095](https://www.github.com/iamturns/create-exposed-app/commit/71f3095e86a370285664903a9a73c7058d747c22))

## Before 8.0.0 (Early 2019)

Changelog captured in [GitHub releases](https://github.com/iamturns/create-exposed-app/releases).

==> create-exposed-app-8.1.1.tgz: package/CHANGELOG.md <==
# Changelog

<!-- markdownlint-disable -->

### [8.1.1](https://www.github.com/iamturns/create-exposed-app/compare/v8.1.0...v8.1.1) (2021-03-13)


### Bug Fixes

* template error ([#131](https://www.github.com/iamturns/create-exposed-app/issues/131)) ([0773731](https://www.github.com/iamturns/create-exposed-app/commit/0773731fde6903891eedab6adb11474592aa7b32))

## [8.1.0](https://www.github.com/iamturns/create-exposed-app/compare/v8.0.1...v8.1.0) (2021-03-13)

### Features

- include instructions for NPM_TOKEN setup ([#126](https://www.github.com/iamturns/create-exposed-app/issues/126)) ([aa51d3c](https://www.github.com/iamturns/create-exposed-app/commit/aa51d3cb7641eed6ea39487f570d39de256988fa))

### Bug Fixes

- failing build script ([#127](https://www.github.com/iamturns/create-exposed-app/issues/127)) ([f7b6004](https://www.github.com/iamturns/create-exposed-app/commit/f7b60044c860854a916df0141f6ba96086d0f375))

### [8.0.1](https://www.github.com/iamturns/create-exposed-app/compare/v8.0.0...v8.0.1) (2021-03-13)

### Bug Fixes

- build badge ([#123](https://www.github.com/iamturns/create-exposed-app/issues/123)) ([1c5ada3](https://www.github.com/iamturns/create-exposed-app/commit/1c5ada36509579bb907ad725a497f0d3008b81e2))

## [8.0.0](https://www.github.com/iamturns/create-exposed-app/compare/v7.2.0...v8.0.0) (2021-03-13)

### ⚠ BREAKING CHANGES

A complete overhaul. Some highlights:

- Dropping CircleCI for Github Action (with auto-formatting, coverage reports, and release management)
- Dropping Babel for ESBuild
- Dropping semantic-release for Release Please

### Features

- Complete overhaul ([#121](https://www.github.com/iamturns/create-exposed-app/issues/121)) ([71f3095](https://www.github.com/iamturns/create-exposed-app/commit/71f3095e86a370285664903a9a73c7058d747c22))

## Before 8.0.0 (Early 2019)

Changelog captured in [GitHub releases](https://github.com/iamturns/create-exposed-app/releases).
